'use strict';

// src/utils.ts
function createFileFilter(options) {
  const { include = [], exclude = [] } = options || {};
  const includePatterns = Array.isArray(include) ? include : [include];
  const excludePatterns = Array.isArray(exclude) ? exclude : [exclude];
  return function filter(filename) {
    if (includePatterns.length === 0 && excludePatterns.length === 0) {
      return true;
    }
    for (const pattern of excludePatterns) {
      if (matchPattern(filename, pattern)) {
        return false;
      }
    }
    if (includePatterns.length === 0) {
      return true;
    }
    for (const pattern of includePatterns) {
      if (matchPattern(filename, pattern)) {
        return true;
      }
    }
    return false;
  };
}
function matchPattern(filename, pattern) {
  if (pattern instanceof RegExp) {
    return pattern.test(filename);
  }
  if (typeof pattern === "string") {
    return filename.includes(pattern);
  }
  if (typeof pattern === "function") {
    return pattern(filename);
  }
  return false;
}

exports.createFileFilter = createFileFilter;
